{% extends 'portal/base.html' %}
{% load static %}

{% block content %}
<div id="added_independent_student_to_class"></div>

<section class="background col-sm-6 col-center">
    <h4>External student added to class {{ class.name }} ({{ class.access_code }})</h4>
</section>

<div class="col-sm-8 col-center">
    <p>The student has been successfully added to the class {{ class.name }}.</p>
    <p>Please provide the student with their new login details:</p>
</div>

<div class="background--primary">
    <div class="col-sm-8 col-center">
        <p><strong>Class Access Code:</strong> {{ class.access_code }}</p>
        <p><strong>Name:</strong> {{ student.new_user.first_name }}</p>
    </div>
</div>

<div class="col-sm-8 col-center">
    <p>{{ student.new_user.first_name }} should now login as a student with these details.</p>
    <p>{{ student.new_user.first_name }}&rsquo;s password is unchanged. You may manage this student,
        including changing their name and password, as with other students.</p>

    <div class="background">
        <p><a id="return_button" href="{% url 'view_class' class.access_code %}">&#10229; Back to Class</a></p>
    </div>
</div>

{% endblock %}