<h6>Strictly Necessary Cookies</h6>

<table class="table table-bordered header-primary">
    <colgroup>
        <col span="1" style="width: 23%;">
        <col span="1" style="width: 20%;">
        <col span="1" style="width: 47%;">
        <col span="1" style="width: 10%;">
    </colgroup>
    <tr>
        <th><strong>Cookie name</strong></th>
        <th><strong>Host</strong></th>
        <th><strong>Description</strong></th>
        <th><strong>Expiry</strong></th>
    </tr>
    <tr>
        <td><p>OptanonAlertBoxClosed</p></td>
        <td><p>codeforlife.education</p></td>
        <td><p>This cookie is set by the cookie compliance solution from OneTrust. It is set after visitors have
            seen a cookie information notice and in some cases only when they actively close the notice down. It
            enables the website not to show the message more than once to a user. It contains no personal
            information.</p>
        </td>
        <td><p>1 year</p></td>
    </tr>
    <tr>
        <td><p>OptanonConsent</p></td>
        <td><p>codeforlife.education</p></td>
        <td><p>This cookie is set by the cookie compliance solution from OneTrust. It stores information about
            the categories of cookies the site uses and whether visitors have given or withdrawn consent for the
            use of each category. This enables site owners to prevent cookies in each category from being set in
            the users browser, when consent is not given. It contains no information that can identify the site
            visitor.</p>
        </td>
        <td><p>1 year</p></td>
    </tr>
    <tr>
        <td><p>csrftoken</p></td>
        <td><p>codeforlife.education</p></td>
        <td><p>This cookie is associated with the Django web development platform for Python. It is designed to
            help protect a site against a particular type of software attack on web forms.</p>
        </td>
        <td><p>1 year</p></td>
    </tr>
    <tr>
        <td><p>sessionid</p></td>
        <td><p>codeforlife.education</p></td>
        <td><p>This cookie is associated with the Django web development platform for Python. It contains a
            special session id to identify each browser and its associated session with the site.</p>
        </td>
        <td><p>Session</p></td>
    </tr>
    <tr>
        <td><p>_GRECAPTCHA</p></td>
        <td><p>www.google.com</p></td>
        <td><p>Cookie used by Google Recaptcha. It is used for risk analysis in spam protection and may store
            browsing device information.</p>
        </td>
        <td><p>5 months</p></td>
    </tr>
</table>

<h6>Analytics / Performance Cookies</h6>

<table class="table table-bordered header-primary">
    <colgroup>
        <col span="1" style="width: 23%;">
        <col span="1" style="width: 20%;">
        <col span="1" style="width: 47%;">
        <col span="1" style="width: 10%;">
    </colgroup>
    <tr>
        <th><strong>Cookie name</strong></th>
        <th><strong>Host</strong></th>
        <th><strong>Description</strong></th>
        <th><strong>Expiry</strong></th>
    </tr>
    <tr>
        <td><p>_ga</p></td>
        <td><p>codeforlife.education</p></td>
        <td><p>This cookie is associated with Google Universal Analytics - which is a significant update to
            Google's more commonly used analytics service. This cookie is used to distinguish unique users by
            assigning a randomly generated number as a client identifier. It is included in each page request in
            a site and used to calculate visitor, session and campaign data for the sites analytics reports.</p>
        </td>
        <td><p>1 year</p></td>
    </tr>
    <tr>
        <td><p>_gid</p></td>
        <td><p>codeforlife.education</p></td>
        <td><p>This cookie is associated with Google Universal Analytics. It is used to store and count page
            views.</p>
        </td>
        <td><p>A few seconds</p></td>
    </tr>
    <tr>
        <td><p>_ga_xxxxxxxxxx</p></td>
        <td><p>codeforlife.education</p></td>
        <td><p>This cookie is associated with Google Universal Analytics. Used to distinguish unique users by
            assigning a randomly generated number as a client identifier. Its primary purpose is to help website
            owners measure visitor interactions, track site usage, and provide personalised experiences to
            enhance user engagement.</p>
        </td>
        <td><p>1 year</p></td>
    </tr>
    <tr>
        <td><p>_gat_UA-xxxxxxxx-x</p></td>
        <td><p>codeforlife.education</p></td>
        <td><p>This cookie is associated with Google Tag Manager. It is used to store to provide technical
            monitoring and limit the amount of data recorded by Google on high-traffic sites.</p>
        </td>
        <td><p>1 minute</p></td>
    </tr>
    <tr>
        <td><p>_gat_gtag_UA_xxxxxxxx_x</p></td>
        <td><p>codeforlife.education</p></td>
        <td><p>This cookie is associated with Google Tag Manager. It is used to store a unique user ID.</p>
        </td>
        <td><p>1 minute</p></td>
    </tr>
</table>

<h6>Functional Cookies</h6>

<table class="table table-bordered header-primary">
    <colgroup>
        <col span="1" style="width: 23%;">
        <col span="1" style="width: 20%;">
        <col span="1" style="width: 47%;">
        <col span="1" style="width: 10%;">
    </colgroup>
    <tr>
        <th><strong>Cookie name</strong></th>
        <th><strong>Host</strong></th>
        <th><strong>Description</strong></th>
        <th><strong>Expiry</strong></th>
    </tr>
    <tr>
        <td><p>preferredLanguage</p></td>
        <td><p>codeforlife.education</p></td>
        <td><p>This cookie is used to remember your selected language preference in Rapid Router and Python Den,
            so you don't have to keep selecting it every time you load a new level.</p>
        </td>
        <td><p>Session</p></td>
    </tr>
    <tr>
        <td><p>muted</p></td>
        <td><p>codeforlife.education</p></td>
        <td><p>This cookie is used to remember your muted setting in Rapid Router and Python Den, so you don't
            have to keep setting it every time you load a new level.</p>
        </td>
        <td><p>Session</p></td>
    </tr>
    <tr>
        <td><p>__cf_bm</p></td>
        <td><p>pwnedpasswords.com</p></td>
        <td><p>This cookie is used by CloudFlare to read and filter requests from bots.</p>
        </td>
        <td><p>30 minutes</p></td>
    </tr>
</table>