{% extends 'portal/base.html' %}
{% load static %}

{% block content %}
<div class="error-page background container">
    <div class="row mx-0 d-flex justify-content-between">
        <div class="flex-grow-1">
            <h2>Temporary lock out!</h2>
            <h5>Your account has been temporarily blocked as there were too many unsuccessful requests.</h5>
            <p>If you wish to proceed, please ask your teacher to reset your password.
            Alternatively, you will need to wait 24 hours for your account to be unlocked again.</p>
        </div>
        <img title="Phil" alt="Phil" src="{% static 'portal/img/phil.png' %}"/>
    </div>
</div>
{% endblock content %}
