{% extends 'portal/base.html' %}
{% load static %}
{% load app_tags %}
{% load banner_tags %}

{% block subNav %}
{% banner banner_name="BANNER" %}
{% endblock subNav %}

{% block content %}
<div class="background container">
    <section>
        <h3>How to get involved and gain experience</h3>
    </section>
    <div class="row">
        <div class="col-sm-6">
            <p>Code for Life would not have been possible without the dedication
                of our volunteers.</p>
            <p>In 2014, computing was added to the UK curriculum, requiring
                schools to teach coding principles and programming foundations.</p>
        </div>
        <div class="col-sm-6">
            <p>Recognising a need to support teachers and students in navigating
                the uncharted territory, Ocado Technology deployed an army of
                internal volunteers who worked after hours, fuelled by free
                pizzas and fizzy drinks.</p>
            <p>What came out of this, is what you see today, used by educators
                and learners from over 180 countries. Our products are
                open-source and free forever.</p>
        </div>
    </div>
    <div class="text-right">
        <a href="https://docs.codeforlife.education/" target="_blank"
           class="button button--primary button-right-arrow">
            Read our developer guide
        </a>
    </div>
</div>

<div class="background background--primary">
    <div class="container">
        <div class="row d-flex flex-column-reverse flex-md-row">
            <div class="col-12 col-md-6 order-1 order-md-0">
                <h4>Our products</h4>

                <p><b>The website</b></p>
                <p>This is the gateway for users to get to know who we are and
                    what we do. It hosts our web-based games and plenty of
                    teaching resources, and the teacher dashboard for class
                    management.</p>

                <p><b>Rapid Router</b></p>
                <p>An introduction to coding that is aimed at ages 5 to 14.
                    Built on Blockly, it's a visual programming language similar
                    to Scratch. Rapid Router is our flagship game with the
                    biggest user base.</p>

                <p><b>Python Den</b></p>
                <p>Our new Python Den uses Blockly, Blockly/Python split
                    screen, and an IDE. It takes students from no previous
                    Python experience to a foundation in Python, helping
                    prepare them for GCSE and beyond.</p>
            </div>
            <div class="col-12 col-md-6 order-0 order-md-1">
                <img title="Rapid Router" alt="Rapid Router"
                     src="{% static 'portal/img/rapidrouter.png' %}" class="img-fluid">
            </div>
        </div>
    </div>
</div>

<div class="background container">
    <div class="row">
        <div class="col-sm-6 bg-image">
            <img title="Gitbook" alt="Gitbook"
                 src="{% static 'portal/img/gitbook.png' %}" class="img-border">
        </div>
        <div class="col-sm-6">
            <h4>How you can contribute</h4>
            <p>Today, there is a small dedicated team working full-time on Code
                for Life. Our community, made up of dedicated teachers, tutors,
                students, and volunteers, has played a vital part in Code For
                Life's growth. The resources and games are aligned to the UK
                National Curriculum and have reached over 260,000 active users
                across 180 countries, and over 660,000 users since the launch in
                2014. We need your help to grow even more.</p>
            <p>If contributing to open-source projects to support education in
                coding and technology sounds exciting for you, we'd love to have
                you on board!</p>
            <div class="text-right">
                <a href="https://docs.codeforlife.education/" target="_blank"
                   class="button button--primary button-right-arrow">
                    Read our developer guide
                </a>
            </div>
        </div>
    </div>
</div>

{% endblock content %}
