{% load static %}
{% load app_tags %}
<!DOCTYPE html>
<html>
<head>
    <title>Code For Life - there has been an error</title>

    {% include "common/onetrust_cookies_consent_notice.html" %}

    <link rel="stylesheet" type="text/css" href="{% static 'portal/css/portal.css' %}">
    <link href="https://fonts.googleapis.com/css2?family=Space+Grotesk:wght@500&display=swap" rel="stylesheet">
    <link href="https://fonts.googleapis.com/css2?family=Inter:wght@400;500;600&display=swap" rel="stylesheet">
    <link rel="shortcut icon" href="{% static 'portal/img/favicon.ico' %}" type="image/x-icon">
    <link rel="icon" href="{% static 'portal/img/favicon.ico' %}" type="image/x-icon">
</head>
<body>

<div class="content-footer-wrapper">
    <div id="contentWrapper">
        {% block topBar %}
        {% include 'portal/partials/header.html' %}
        {% endblock topBar %}

        <div class="content">
            <div class="error-page background container">
                <div class="row mx-0 d-flex justify-content-between">
                    <div class="flex-grow-1">
                        <h2>Zap!</h2>
                        <h5>Oh dear! Something technical has gone wrong.</h5>
                        <p>Dee will attempt to fix this soon.</p>
                        <a class="button button--primary" href="{% url 'home' %}">Back to homepage</a>
                    </div>
                    <img title="Dee" alt="Dee" src="{% static 'portal/img/dee.png' %}"/>
                </div>
            </div>
        </div>

        <div class="push"></div>
    </div>

    {% block footer %}
        {% include 'portal/partials/footer.html' %}
    {% endblock footer %}
</div>

</body>
</html>
