{% extends 'portal/form_shapes.html' %}
{% load static %}
{% load app_tags %}

{% block form_content %}
    <h4>Your email address verification failed</h4>
    <img class="background" title="Sad Face" alt="Verification failure" src="{% static 'portal/img/sadface.png' %}">
    <p class="text-left">You used an invalid link, either you mistyped the URL or that link is expired.</p>
    <p class="text-left">When you next attempt to log in, you will be sent a new verification email.</p>
    <div>
        {% if usertype == "TEACHER" %}
            <a href="{% url 'home' %}" class="button button--primary button--login">Back to homepage</a>
        {% else %}
            <a href="{% url 'home' %}" class="button button--home">Back to homepage</a>
        {% endif %}
    </div>
{% endblock form_content %}
