<div class="form__checkbox">
    <div class="form__checkbox-input">
        {{ newsletter_ticked }}
    </div>
    <p class="semi-bold">Sign up to receive updates about Code for Life games and teaching resources.</p>
</div>
