{% extends 'portal/base.html' %}
{% load static %}

{% block content %}

<div class="error-page background container">
    <div class="row mx-0 d-flex justify-content-between">
        <div class="flex-grow-1">
            <h2>Uh oh!</h2>
            <h5>Sorry, Nigel can't find the page you were looking for.</h5>
            <p>This might be because you have entered a web address incorrectly or the page has moved.</p>
        </div>
        <img title="Nigel" alt="Nigel" src="{% static 'portal/img/nigel.png' %}"/>
    </div>

</div>

{% endblock content %}
