// General Palette
$color-primary-50: #ff9abc;
$color-primary-100: #ff6699;
$color-primary-200: #ff397c;
$color-primary-300: #fa1664;
$color-primary-400: #ee0857;
$color-primary-500: #e0004d;
$color-primary-600: #d40149;
$color-primary-700: #c90548;
$color-primary-800: #be0947;
$color-primary-900: #a60039;
$color-primary: $color-primary-500;
$color-primary-variant: $color-primary-200;

$color-secondary-50: #ffedad;
$color-secondary-100: #ffe382;
$color-secondary-200: #ffda5c;
$color-secondary-300: #ffd23b;
$color-secondary-400: #ffc709;
$color-secondary-500: #f6be00;
$color-secondary-600: #eab502;
$color-secondary-700: #dead06;
$color-secondary-800: #cfa30b;
$color-secondary-900: #bf9400;
$color-secondary: $color-secondary-500;
$color-secondary-variant: $color-secondary-200;

$color-tertiary-50: #85ddff;
$color-tertiary-100: #4dceff;
$color-tertiary-200: #27c4ff;
$color-tertiary-300: #08bafc;
$color-tertiary-400: #04afef;
$color-tertiary-500: #00a3e0;
$color-tertiary-600: #0099d2;
$color-tertiary-700: #008cc1;
$color-tertiary-800: #007faf;
$color-tertiary-900: #01668c;
$color-tertiary: $color-tertiary-500;
$color-tertiary-variant: $color-tertiary-200;
// Old palette
$color-teacher-blue: #0c52a3;
$color-student-orange: #f37300;
$color-text-gray: #383b3b;
$color-error: #d60026;
// Text
$color-text-primary: black;
$color-text-secondary: white;
$color-text-tertiary: $color-text-gray;
$color-text-login-error: #ffff00;
$color-text-disabled: #9b9b9b;
$color-text-primary-disabled: #7A5F01;
// Quotes
$color-quote-text: $color-text-gray;
$color-quote-name: $color-text-gray;
// Buttons
$color-button-home: white;
$color-button-home-hover: #f6f5f5;
$color-button-home-border: #6e7171;
$color-button-contained: $color-secondary-300;
$color-button-contained-hover: $color-secondary-400;
$color-button-contained-active: $color-secondary-400;
$color-button-contained-disabled: $color-secondary-100;
$color-button-outlined-border: $color-secondary-600;
$color-button-outlined-border-active: $color-secondary-600;
$color-button-subnav-border: white;
// Old buttons
$color-button-primary-action-navigation: $color-secondary;
$color-button-primary-action-navigation-hover: $color-secondary;
$color-button-primary-action-positive: #7ed321;
$color-button-primary-action-positive-hover: #2dbf00;
$color-button-primary-action-negative: #ff637d;
$color-button-primary-action-negative-hover: #fd3d6a;
$color-button-primary-action-danger: #ff0000;
$color-button-primary-action-danger-hover: #df0531;
$color-button-primary-action-danger-disabled: #E76A6A;
$color-button-primary-action-setup: #fab300;
$color-button-primary-action-setup-hover: #ff9500;
$color-button-secondary-border-light: white;
$color-button-secondary-border-dark: $color-secondary-600;
$color-button-border: $color-secondary-600;
$color-button-border-teacher: $color-teacher-blue;
$color-button-border-student: $color-student-orange;
$color-button-border-light-grey: #e0e0e0;
$color-button-disabled: #d8d8d8;
$color-button-menu-item: #f0f0f0;
// Tabs
$color-tab-border: $color-teacher-blue;
$color-tab-selected-text: white;
$color-tab-selected-background: $color-teacher-blue;
$color-tab-unselected-text: $color-teacher-blue;
$color-tab-unselected-background: white;
// Tables
$color-table-header-primary: #6e7171;
$color-table-header-secondary: #9a9c9e;
$color-table-border: #9b9b9b;
// Backgrounds
$color-background-primary: $color-primary;
$color-background-secondary: white;
$color-background-tertiary: $color-text-gray;
$color-background-teach: $color-primary;
$color-background-play: $color-tertiary;
$color-background-play-indep: $color-secondary;
$color-banner-games: rgba(0, 0, 0, 0.5);
$color-background-warning: #ffbc50;
$color-background-positive: #7ed321;
$color-background-danger: #ff0000;
$color-background-tint-primary: #f1ecec;
$color-background-sub-banner: $color-secondary-300;
$color-background-box-shadow: rgba(0, 0, 0, 0.2);
$color-background-python-den: #213ce7;
// Popups & Messages
$color-ui-dialog-border: #808080;
$color-ui-widget-overlay: #666666;
$color-popup-overlay: rgba(0, 0, 0, 0.5);
$color-message-border: #808080;
// Password strength checker
$color-password-strength-icon-border: white;
// Carousel
$color-carousel-inactive-indicator: #d8d8d8;
