{% load static %}
{% load app_tags %}

<div class="footer">
    <div class="container">
        <div class="row">
            <div class="col-sm-8">
                <div class="footer-links is-flex">
                    <div class="col-sm-4 col-xs-12">
                        <p><a href="{% url 'about' %}">About us</a></p>
                        <p><a class="freshdesk__contact-us">Help and support</a></p>
                        <p><a href="https://2662351606-files.gitbook.io/~/files/v0/b/gitbook-x-prod.appspot.com/o/spaces%2F-M_6UDUiGoJDhr_OXetO%2Fuploads%2FHx2kJLPwUER9Ez7gdQFp%2F2023_Impact_Report_Final.pdf?alt=media"
                              target="_blank">Impact Report 2023</a></p>
                        <p><a href="https://2662351606-files.gitbook.io/~/files/v0/b/gitbook-x-prod.appspot.com/o/spaces%2F-M_6UDUiGoJDhr_OXetO%2Fuploads%2FzLy8JN9TSFpzunetkWET%2FImpact_Report_24.V.10.pdf?alt=media"
                              target="_blank">Impact Report 2024</a></p>
                    </div>
                    <div class="col-sm-4 col-xs-12">
                        <p><a href="{% url 'privacy_notice' %}">Privacy notice</a></p>
                        <p><a href="{% url 'terms' %}">Terms of use</a></p>
                        <p><a class="optanon-toggle-display">Cookie settings</a></p>
                        <p><a href="https://docs.codeforlife.education/">CFL community</a></p>
                    </div>
                    <div class="col-sm-4 col-xs-12">
                        <p><a href="{% url 'home-learning' %}">Home learning</a></p>
                        <p><a href="{% url 'getinvolved' %}">Get involved</a></p>
                        <p><a href="{% url 'codingClub' %}">Coding clubs</a></p>
                        <p><a href="https://2662351606-files.gitbook.io/~/files/v0/b/gitbook-x-prod.appspot.com/o/spaces%2F-M_6UDUiGoJDhr_OXetO%2Fuploads%2FPavvCifcuUeZZZLkV01C%2FOpportunities%20with%20Code%20for%20Life.pdf?alt=media"
                              target="_blank">Opportunities with CFL</a></p>
                    </div>
                </div>
            </div>
            <div class="col-sm-4 hidden-xs">
                <a target="_blank" href="https://www.ocadogroup.com/sustainability/sustainability">
                    <img title="Ocado Group" alt="Ocado Group" src="{% static 'portal/img/logo_cfl_powered.svg' %}">
                </a>
            </div>
        </div>
        <div class="row">
            <form id="newsletter_form" action="{% url 'process_newsletter_form' %}" method="post">
                <div class="col-sm-8">
                    <div>
                        {{ news_form.non_field_errors }}
                        <div class="form--row">
                            <div class="form--row__input">
                                <label>{{ news_form.email.label }}</label>
                                <div class="input--icon">
                                    {{ news_form.email }}
                                    <span class="iconify" data-icon="mdi:email-outline"></span>
                                </div>
                                <small>{{ news_form.email.help_text }}</small>
                                {{ news_form.email.errors }}
                            </div>
                        </div>
                        <div class="form--row justify-content-between">
                            <div class="form__checkbox">
                                <div class="form__checkbox-input">
                                    {{ news_form.age_verification }}
                                </div>
                                <p class="p-0">Please confirm that you are over 18.</p>
                            </div>
                            <button type="submit" id="submit_newsletter" name="submit" value="Submit" class="button button--primary m-0">Sign up</button>
                        </div>
                    </div>
                    <div class="social-media">
                        <a target="_blank" href="https://www.facebook.com/codeforlifeuk/"><span class="iconify" data-icon="simple-icons:facebook"></span></a>
                        <a target="_blank" href="https://www.instagram.com/codeforlife_uk/"><span class="iconify" data-icon="simple-icons:instagram"></span></a>
                        <a target="_blank" href="https://www.linkedin.com/company/code-for-life-uk/"><span class="iconify" data-icon="simple-icons:linkedin"></span></a>
                        <a target="_blank" href="https://twitter.com/codeforlifeuk"><span class="iconify" data-icon="ri:twitter-x-line"></span></a>
                        <a target="_blank" href="https://www.youtube.com/@CodeForLife-uk"><span class="iconify" data-icon="simple-icons:youtube"></span></a>
                    </div>
                    <div class="visible-xs">
                        <a target="_blank" href="https://www.ocadogroup.com/sustainability/sustainability">
                            <img title="Ocado Group" alt="Ocado Group" src="{% static 'portal/img/logo_cfl_powered.svg' %}">
                        </a>
                    </div>
                </div>
                <div class="col-sm-4">
                    <div class="is-flex justify-content-center justify-content-sm-end">
                        <img title="10 years anniversary" alt="10 years anniversary" src="{% static 'portal/img/10_years_anniversary.png' %}">
                    </div>
                </div>
            </form>
        </div>
        <p class="copyright">&copy; Ocado Group {% now "Y" %}</p>
    </div>
</div>
