<div class="banner banner--teacher">
    <div class="container">
        <div class="row">
            <div class="col-sm-12 d-flex">
                <div>
                    <h1 class="banner__text--primary">{{ title }}</h1>
                    {% if subtitle %}
                        <h4>{{ subtitle }}</h4>
                    {% endif %}
                    {% if text %}
                        <p>{{ text }}</p>
                    {% endif %}
                    <div class="button-group">
                        {% if button %}
                            {% if button.external %}
                                <a href="{{ button.link }}" target="_blank" class="button button--primary button-right-arrow">{{ button.text }}</a>
                            {% else %}
                                <a href="{% url button.link %}" class="button button--primary button-right-arrow">{{ button.text}}</a>
                            {% endif %}
                        {% endif %}
                        {% if button2 %}
                            {% if button.external %}
                                <a href="{{ button2.link }}" target="_blank" class="button button--primary button-right-arrow">{{ button2.text }}</a>
                            {% else %}
                                <a href="{% url button2.link %}" class="button button--primary button-right-arrow">{{ button2.text}}</a>
                            {% endif %}
                        {% endif %}
                    </div>
                </div>
                <div>
                    <div class="banner--picture">
                        <div class="banner--picture__inside1">
                            <div class="banner--picture__inside2 {{ image_class }}"
                                 {% if image_description %}title="{{ image_description }}"{% endif %}
                                 {% if alt %} alt="{{ alt }}" {% endif %}>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
