@import "base";

.alternative-section {
  border-top: 1px solid $color-text-tertiary;
}

.row--small {
  @include _padding($spacing * 5, 0px, 0px, 0px);
}

.row--regular {
  @include _padding($spacing * 10, 0px, $spacing * 10, 0px);
}

.row--under {
  @include _padding(0px, 0px, $spacing * 4, 0px);
}

.top-element {
  @include _margin($spacing * 16, 0px, 0px, 0px);
}

.is-flex {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -ms-flex-wrap: wrap;
  -webkit-flex-wrap: wrap;
  flex-wrap: wrap;

  [class^="col-"] {
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -webkit-flex-direction: column;
    -ms-flex-direction: column;
    display: -webkit-box;
    display: -webkit-flex;
    display: -ms-flexbox;
    display: flex;
    flex-direction: column;
  }

  img {
    align-self: center;
  }
}

.flex-grow-1 {
  flex-grow: 1;
}

.mw-0 {
  max-width: 0;
}

.img-aspect-fill {
  object-fit: cover;
  width: 100%;
}

.is-flex-item {
  flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
}

.hide {
  display: none;
}

.popup-wrapper {
  padding: 0;
}

.password-strength-container {
  align-items: center;
  display: inline-flex;
  justify-content: center;
}

.center-flex {
  justify-content: center;
}

.password-strength-sign {
  border: 1px solid $color-password-strength-icon-border;
  border-radius: 50%;
  display: block;
  height: 15px;
  margin: auto;
  width: 15px;
}

.password-strength-text {
  @include _padding(0px, 0px, 0px, $spacing * 2);
  font-weight: 500;
}

.password-strength-text-old {
  @include _padding(0px, 0px, 0px, $spacing * 2);
  color: $color-text-primary;
  font-style: italic;
}

section {
  text-align: center;

  button,
  .button {
    @include _margin(30px, 20px, 0px, 20px);
  }

  .youtube img {
    @include _margin($spacing * 6, 0px, $spacing * 6, 0px);
  }
}

.col-center {
  float: none;
  margin-left: auto;
  margin-right: auto;
}

#faqs {
  answer,
  input {
    display: none;
    margin-left: 8px;
  }

  input:checked + label:before {
    content: "\2013";
  }

  input:checked ~ answer {
    display: block;
  }
  input + label:before {
    content: "+";
  }
}

.tab {
  list-style-type: none;
  margin: auto;
  overflow: hidden;
  padding: 0;
  width: auto;

  li {
    float: left;
    width: 50%;

    a {
      @include _font-size(20px);
      @include _padding($spacing * 2, 16px, $spacing * 2, 16px);
      background-color: $color-tab-unselected-background;
      border: 1px solid $color-tab-unselected-text;
      color: $color-tab-unselected-text;
      display: inline-block;
      text-align: center;
      text-decoration: none;
      transition: 0.3s;
      width: 100%;
    }

    img {
      display: block;
      margin: auto;
      position: relative;
    }

    .active {
      background-color: $color-tab-selected-background;
      color: $color-tab-selected-text;
    }
  }
}

.tabcontent {
  @include _padding(6px, 0px, 6px, 0px);
  display: none;
  width: 100%;
}

iframe {
  border: none;
}

input.input-invalid {
  border-color: $color-error;
}

@media (max-width: $tablet-large-max-width) {
  .col-sm-offset-2 {
    margin-left: 8.333%;
  }

  .col-center {
    width: 90%;
  }
}

@media (min-width: $tablet-small-min-width) {
  .row--flex {
    display: flex;
  }

  .col-sm-3 {
    width: 25%;
  }
}

@media (max-width: $mobile-max-width) {
  .col-sm-offset-2 {
    margin-left: 0;
  }

  .row--regular {
    padding: 0;
  }
}
